/* c-irrlicht --- C bindings for Irrlicht Engine

   Copyright (C) 2019 Javier Sancho <jsf@jsancho.org>

   This file is part of c-irrlicht.

   c-irrlicht is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   c-irrlicht is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with guile-irrlicht.  If not, see
   <http://www.gnu.org/licenses/>.
*/

#include <irrlicht/irrlicht.h>
#include "ISceneManager.h"

extern "C" {
  irr_scene_IAnimatedMeshSceneNode*
  irr_scene_ISceneManager_addAnimatedMeshSceneNode(irr_scene_ISceneManager* smgr,
                                                   irr_scene_IAnimatedMesh* mesh,
                                                   irr_scene_ISceneNode* parent,
                                                   int32_t id,
                                                   irr_core_vector3df* position,
                                                   irr_core_vector3df* rotation,
                                                   irr_core_vector3df* scale,
                                                   bool alsoAddIfMeshPointerZero)
  {
    const irr::core::vector3df& iPosition = irr::core::vector3df(position->x,
                                                                 position->y,
                                                                 position->z);
    const irr::core::vector3df& iRotation = irr::core::vector3df(rotation->x,
                                                                 rotation->y,
                                                                 rotation->z);
    const irr::core::vector3df& iScale = irr::core::vector3df(scale->x,
                                                              scale->y,
                                                              scale->z);
    return (irr_scene_IAnimatedMeshSceneNode*)
      ((irr::scene::ISceneManager*)smgr)->addAnimatedMeshSceneNode((irr::scene::IAnimatedMesh*)mesh,
                                                                   (irr::scene::ISceneNode*)parent,
                                                                   id,
                                                                   iPosition,
                                                                   iRotation,
                                                                   iScale,
                                                                   alsoAddIfMeshPointerZero);
  }

  irr_scene_ICameraSceneNode*
  irr_scene_ISceneManager_addCameraSceneNode(irr_scene_ISceneManager* smgr,
                                             irr_scene_ISceneNode* parent,
                                             irr_core_vector3df* position,
                                             irr_core_vector3df* lookat,
                                             int32_t id,
                                             bool makeActive)
  {
    const irr::core::vector3df& iPosition = irr::core::vector3df(position->x,
                                                                 position->y,
                                                                 position->z);
    const irr::core::vector3df& iLookat = irr::core::vector3df(lookat->x,
                                                               lookat->y,
                                                               lookat->z);
    return (irr_scene_ICameraSceneNode*)
      ((irr::scene::ISceneManager*)smgr)->addCameraSceneNode((irr::scene::ISceneNode*)parent,
                                                             iPosition,
                                                             iLookat,
                                                             id,
                                                             makeActive);
  }

  void
  irr_scene_ISceneManager_drawAll(irr_scene_ISceneManager* smgr)
  {
    ((irr::scene::ISceneManager*)smgr)->drawAll();
  }


  irr_scene_IAnimatedMesh*
  irr_scene_ISceneManager_getMesh(irr_scene_ISceneManager* smgr,
                                  const char* filename)
  {
    return (irr_scene_IAnimatedMesh*)
      ((irr::scene::ISceneManager*)smgr)->getMesh(filename);
  }
}
